@@ -35,7 +35,7 @@ if TYPE_CHECKING:
     from google.api_core import operation
     from google.cloud.run_v2.types import Execution
 
-    from airflow.utils.context import Context
+    from airflow.providers.common.compat.sdk import Context
 
 
 class CloudRunCreateJobOperator(GoogleCloudBaseOperator):
@@ -141,7 +141,7 @@ class CloudRunUpdateJobOperator(GoogleCloudBaseOperator):
 
 class CloudRunDeleteJobOperator(GoogleCloudBaseOperator):
     """
-    Deletes a job and wait for the the operation to be completed. Pushes the deleted job to xcom.
+    Deletes a job and wait for the operation to be completed. Pushes the deleted job to xcom.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
