@@ -39,6 +39,7 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
     LIST_URL,
     NAME,
     PATH,
+    PROJECT_ID,
     SCHEDULE,
     SCHEDULE_END_DATE,
     SCHEDULE_START_DATE,
@@ -47,6 +48,10 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
     STATUS,
     TRANSFER_SPEC,
 )
+from airflow.providers.google.cloud.openlineage.facets import (
+    CloudStorageTransferJobFacet,
+    CloudStorageTransferRunFacet,
+)
 from airflow.providers.google.cloud.operators.cloud_storage_transfer_service import (
     CloudDataTransferServiceCancelOperationOperator,
     CloudDataTransferServiceCreateJobOperator,
@@ -246,10 +251,10 @@ class TestTransferJobValidator:
     @pytest.mark.parametrize(
         "transfer_spec",
         [
-            {**SOURCE_AWS, **SOURCE_GCS, **SOURCE_HTTP},  # type: ignore[arg-type]
+            {**SOURCE_AWS, **SOURCE_GCS, **SOURCE_HTTP},
             {**SOURCE_AWS, **SOURCE_GCS},
-            {**SOURCE_AWS, **SOURCE_HTTP},  # type: ignore[arg-type]
-            {**SOURCE_GCS, **SOURCE_HTTP},  # type: ignore[arg-type]
+            {**SOURCE_AWS, **SOURCE_HTTP},
+            {**SOURCE_GCS, **SOURCE_HTTP},
         ],
     )
     def test_verify_data_source(self, transfer_spec):
@@ -382,7 +387,7 @@ class TestGcpStorageTransferJobCreateOperator:
     # fields
     @pytest.mark.db_test
     @pytest.mark.parametrize(
-        "body, excepted",
+        ("body", "excepted"),
         [(VALID_TRANSFER_JOB_JINJA, VALID_TRANSFER_JOB_JINJA_RENDERED)],
     )
     @mock.patch(
@@ -1018,6 +1023,160 @@ class TestS3ToGoogleCloudStorageTransferOperator:
                 context={}, event={"status": "error", "message": "test failure message"}
             )
 
+    @pytest.mark.parametrize(
+        ("wait", "job_name"),
+        [
+            (True, "transferJobs/123"),
+            (False, "transferJobs/456"),
+        ],
+    )
+    def test_get_openlineage_facets_on_complete_facets_run_and_job(self, wait, job_name):
+        op = CloudDataTransferServiceS3ToGCSOperator(
+            task_id=TASK_ID,
+            s3_bucket=AWS_BUCKET_NAME,
+            s3_path="raw/",
+            gcs_bucket=GCS_BUCKET_NAME,
+            gcs_path="processed/",
+            project_id=GCP_PROJECT_ID,
+            wait=wait,
+            description=DESCRIPTION,
+        )
+        op._transfer_job = {
+            NAME: job_name,
+            PROJECT_ID: GCP_PROJECT_ID,
+            DESCRIPTION: DESCRIPTION,
+            STATUS: "ENABLED",
+            TRANSFER_SPEC: {
+                AWS_S3_DATA_SOURCE: {BUCKET_NAME: AWS_BUCKET_NAME, PATH: "raw/"},
+                GCS_DATA_SINK: {BUCKET_NAME: GCS_BUCKET_NAME, PATH: "processed/"},
+            },
+        }
+
+        result = op.get_openlineage_facets_on_complete(task_instance=mock.Mock())
+
+        assert result.inputs[0].namespace == f"s3://{AWS_BUCKET_NAME}"
+        assert result.inputs[0].name == "raw/"
+        assert result.outputs[0].namespace == f"gs://{GCS_BUCKET_NAME}"
+        assert result.outputs[0].name == "processed/"
+
+        job_facet = result.job_facets["cloudStorageTransferJob"]
+        assert isinstance(job_facet, CloudStorageTransferJobFacet)
+        assert job_facet.jobName == job_name
+        assert job_facet.projectId == GCP_PROJECT_ID
+        assert job_facet.description == DESCRIPTION
+        assert job_facet.status == "ENABLED"
+        assert job_facet.sourceBucket == AWS_BUCKET_NAME
+        assert job_facet.sourcePath == "raw/"
+        assert job_facet.targetBucket == GCS_BUCKET_NAME
+        assert job_facet.targetPath == "processed/"
+        assert job_facet.objectConditions is None
+        assert job_facet.transferOptions is None
+        assert job_facet.schedule is None
+
+        run_facet = result.run_facets["cloudStorageTransferRun"]
+        assert isinstance(run_facet, CloudStorageTransferRunFacet)
+        assert run_facet.jobName == job_name
+        assert run_facet.wait == wait
+
+    @pytest.mark.parametrize(
+        ("object_conditions", "delete_source"),
+        [
+            ({"includePrefixes": ["2025/"]}, True),
+            (None, False),
+        ],
+    )
+    def test_get_openlineage_facets_on_complete_job_facet_includes_object_conditions_and_options(
+        self, object_conditions, delete_source
+    ):
+        op = CloudDataTransferServiceS3ToGCSOperator(
+            task_id=TASK_ID,
+            s3_bucket=AWS_BUCKET_NAME,
+            gcs_bucket=GCS_BUCKET_NAME,
+            project_id=GCP_PROJECT_ID,
+            object_conditions=object_conditions,
+            transfer_options={"deleteObjectsFromSourceAfterTransfer": delete_source},
+            wait=True,
+        )
+        op._transfer_job = {
+            NAME: "transferJobs/789",
+            PROJECT_ID: GCP_PROJECT_ID,
+            TRANSFER_SPEC: {
+                AWS_S3_DATA_SOURCE: {BUCKET_NAME: AWS_BUCKET_NAME},
+                GCS_DATA_SINK: {BUCKET_NAME: GCS_BUCKET_NAME},
+                "objectConditions": object_conditions,
+                "transferOptions": {"deleteObjectsFromSourceAfterTransfer": delete_source},
+            },
+        }
+
+        result = op.get_openlineage_facets_on_complete(task_instance=mock.Mock())
+        job_facet = result.job_facets["cloudStorageTransferJob"]
+        assert job_facet.projectId == GCP_PROJECT_ID
+        assert job_facet.objectConditions == object_conditions
+        assert job_facet.transferOptions == {"deleteObjectsFromSourceAfterTransfer": delete_source}
+        assert isinstance(job_facet.objectConditions, (dict, type(None)))
+        assert isinstance(job_facet.transferOptions, (dict, type(None)))
+
+    def test_get_openlineage_facets_on_complete_job_facet_without_object_conditions_or_transfer_options(self):
+        op = CloudDataTransferServiceS3ToGCSOperator(
+            task_id=TASK_ID,
+            s3_bucket=AWS_BUCKET_NAME,
+            gcs_bucket=GCS_BUCKET_NAME,
+            wait=True,
+        )
+        op._transfer_job = {
+            NAME: "transferJobs/222",
+            PROJECT_ID: GCP_PROJECT_ID,
+            "transferSpec": {
+                AWS_S3_DATA_SOURCE: {BUCKET_NAME: AWS_BUCKET_NAME},
+                GCS_DATA_SINK: {BUCKET_NAME: GCS_BUCKET_NAME},
+            },
+        }
+
+        result = op.get_openlineage_facets_on_complete(task_instance=mock.Mock())
+        job_facet = result.job_facets["cloudStorageTransferJob"]
+        assert job_facet.objectConditions is None
+        assert job_facet.transferOptions is None
+        assert job_facet.schedule is None
+
+    def test_get_openlineage_facets_on_complete_delete_job_after_completion_still_produces_facets(self):
+        op = CloudDataTransferServiceS3ToGCSOperator(
+            task_id=TASK_ID,
+            s3_bucket=AWS_BUCKET_NAME,
+            gcs_bucket=GCS_BUCKET_NAME,
+            project_id=GCP_PROJECT_ID,
+            delete_job_after_completion=True,
+            wait=True,
+        )
+        op._transfer_job = {NAME: "transferJobs/333", PROJECT_ID: GCP_PROJECT_ID}
+
+        result = op.get_openlineage_facets_on_complete(task_instance=mock.Mock())
+
+        assert "cloudStorageTransferJob" in result.job_facets
+        assert "cloudStorageTransferRun" in result.run_facets
+        run_facet = result.run_facets["cloudStorageTransferRun"]
+        assert run_facet.deleteJobAfterCompletion is True
+
+    def test_get_openlineage_facets_on_complete_inputs_outputs_when_paths_missing(self):
+        op = CloudDataTransferServiceS3ToGCSOperator(
+            task_id=TASK_ID,
+            s3_bucket=AWS_BUCKET_NAME,
+            gcs_bucket=GCS_BUCKET_NAME,
+        )
+        op._transfer_job = {
+            NAME: "transferJobs/444",
+            PROJECT_ID: GCP_PROJECT_ID,
+            "transferSpec": {
+                AWS_S3_DATA_SOURCE: {BUCKET_NAME: AWS_BUCKET_NAME},
+                GCS_DATA_SINK: {BUCKET_NAME: GCS_BUCKET_NAME},
+            },
+        }
+
+        result = op.get_openlineage_facets_on_complete(task_instance=mock.Mock())
+        assert result.inputs[0].namespace == f"s3://{AWS_BUCKET_NAME}"
+        assert result.inputs[0].name == ""
+        assert result.outputs[0].namespace == f"gs://{GCS_BUCKET_NAME}"
+        assert result.outputs[0].name == ""
+
 
 class TestGoogleCloudStorageToGoogleCloudStorageTransferOperator:
     def test_constructor(self):
